function [SoS,Y_up] = Phosphate_uptake_model_rbm_no_root_uptake(x,x_schnepf,P1,P2,P3,P4,P5,P6,LD1,LD2,LD3,LD4,LD5,LD6,k,b,v,D,plots,x_points, dx, D2_up,Xexp)
% clc
% clear


C0=x(1);        % initial P concentration value
%F_max=x(2);    % originally root uptake was considered in the model but has been switched off
F_max_m=x(2);   % initial uptake by the hyphae

%initialise the data for the different sample sets
if D==1;        DATA = P1;  LD = LD1;  k = k(1);   d=0; b=b(1);    v=v(1);     T=4;    Days = 14;  Dstring=sprintf('Phosphorous absent, two week,\n replicate two P counts');
elseif D==2;    DATA = P2;  LD = LD2;  k = k(2);   d=0; b=b(2);    v=v(2);     T=4;    Days = 14;  Dstring=sprintf('Phosphorous present, two week,\n replicate one P counts');
elseif D==3;    DATA = P3;  LD = LD3;  k = k(3);   d=0; b=b(3);    v=v(3);     T=4;    Days = 14;  Dstring=sprintf('Phosphorous present, two week,\n replicate two P counts');
elseif D==4;    DATA = P4;  LD = LD4;  k = k(4);   d=0; b=b(4);    v=v(4);     T=5;    Days = 28;  Dstring=sprintf('Phosphorous absent, four week,\n replicate two P counts');
elseif D==5;    DATA = P5;  LD = LD5;  k = k(5);   d=0; b=b(5);    v=v(5);     T=5;    Days = 28;  Dstring=sprintf('Phosphorous absent, four week,\n replicate three P counts');
elseif D==6;    DATA = P6;  LD = LD6;  k = k(6);   d=0; b=b(6);    v=v(6);     T=5;    Days = 28;  Dstring=sprintf('Phosphorous present, four week,\n replicate two P counts');
end


t=28*3600*24;   %time in hours

C = 0*x_points+C0;              %initial concentration
F_max=3.26e-6;                  % Root uptake
tout=[0,3,7,14,28]*3600*24;     %output times


theta = 0.3;        % liquid phase volume fraction
D_l = 1.05e-8;      % diffusion coefficient
fl = 0.308;         % impedence factor
r_m = 5e-4;         % radius of external hyphae [cm]

%stiff differential equation solver ode15 used to compute the uptake
[~,Y_up] = ode15s(@tstep_up,tout,C(2:end-1),[], d, dx, x_points, D, b, v, k, pi, r_m, F_max, F_max_m, theta, D_l, fl, D2_up,C0);

    function [ddt_up, up_f] = tstep_up(t, u, d, dx, x_points, D, b,v, k, pi, r_m, F_max, F_max_m, theta, D_l, fl, D2_up,C0)
        
        u_0 = -(theta*D_l*fl)*(((4/(2*dx))*u(1))+((-1/(2*dx))*u(2)))/...
            ((theta*D_l*fl)*(-3/(2*dx))-F_max);                              %initial phospate concentration at position 0 (updated on each iteration cycle)
        c = [u_0;u;C0];                                                      %initial concentration of solutes at time zero
        
        rho_a = k*exp((b/v).*x_points).*(-((1/v)*(x_points-t*v)));           % hyphae length density
        
        % there is a strong oscillatory response in the model which is
        % caused by the (very) non-smooth function
        %         rho_a(x>(v*t))=0;
        % to damp these oscillations we multiply the P concentration by
        % a heaviside function. The function goes to zero in a
        % differentiable way over 2 grid points
        
        rho_a=rho_a.*1/2.*(1-tanh((x_points-v*t)/(sqrt(2)*4*dx)));          % hyphae length density multipled by heaviside function
        r_myc = (2*pi*r_m).*rho_a.*((F_max_m.*c));                          % uptake of P by hyphae
        ct = (theta*D_l*fl)*D2_up(2:end-1,:)*c-r_myc(2:end-1);              % P concentration
        ddt_up=ct;
        up_f = r_myc;%.*(c./(kappa+c));
        
    end


SoS = sum((DATA-interp1(x_points(2:end-1),Y_up(T,:),Xexp/10)).^2)./sum((DATA-mean(DATA)).^2);
R2=(1-SoS);

%Plot results
if plots
    
    figure(2);
    subplot(3,2,D);
    if T==4 && D == 1
        plot(x_points(2:end-1),Y_up(T,:),'-b',(Xexp/10),DATA,'xb','LineWidth',2,'MarkerSize',8)
        title('Phosphate concentration in the soil');
        xlabel('Distance x [cm]');
        ylabel('C_t_o_t [\mumol\cdotcm^-^3]');
        legend([num2str(Days),' day model'],Dstring);
        %             axis tight
        xlim([0 4.5])
        ylim([4.3e-5 14e-5])
        grid on
        yyaxis right
        plot(x_schnepf,LD,'--b')
        legend([num2str(Days),' day model'],Dstring,'hyphal length densities')
        ylabel(sprintf('Hyphal length density\n \\rho [cm\\cdotcm^-^3]'),'color', 'k');
        ax = gca;
        ax.YColor = 'k'
        
    elseif T==4 && D == 2
        plot(x_points(2:end-1),Y_up(T,:),'-b',(Xexp/10),DATA,'xb','LineWidth',2,'MarkerSize',8)
        title('Phosphate concentration in the soil');
        xlabel('Distance x [cm]');
        ylabel('C_t_o_t [\mumol\cdotcm^-^3]');
        legend([num2str(Days),' day model'],Dstring);
        %             axis tight
        xlim([0 4.5])
        ylim([4.4e-5 15e-5])
        grid on
        yyaxis right
        plot(x_schnepf,LD,'--b')
        legend([num2str(Days),' day model'],Dstring,'hyphal length densities')
        ylabel(sprintf('Hyphal length density\n \\rho [cm\\cdotcm^-^3]'),'color', 'k');
        ax = gca;
        ax.YColor = 'k'
        
    elseif T==4 && D == 3
        plot(x_points(2:end-1),Y_up(T,:),'-b',(Xexp/10),DATA,'xb','LineWidth',2,'MarkerSize',8)
        title('Phosphate concentration in the soil');
        xlabel('Distance x [cm]');
        ylabel('C_t_o_t [\mumol\cdotcm^-^3]');
        legend([num2str(Days),' day model'],Dstring);
        %             axis tight
        xlim([0 4.5])
        ylim([4.8e-5 14e-5])
        grid on
        yyaxis right
        plot(x_schnepf,LD,'--b')
        legend([num2str(Days),' day model'],Dstring,'hyphal length densities')
        ylabel(sprintf('Hyphal length density\n \\rho [cm\\cdotcm^-^3]'),'color', 'k');
        ax = gca;
        ax.YColor = 'k'
        
    elseif T==5 && D == 4
        plot(x_points(2:end-1),Y_up(T,:),'-r',(Xexp/10),DATA,'xr','LineWidth',2,'MarkerSize',8)
        title('Phosphate concentration in the soil');
        xlabel('Distance x [cm]');
        ylabel('C_t_o_t [\mumol\cdotcm^-^3]');
        legend([num2str(Days),' day model'],Dstring);
        %             axis tight
        xlim([0 4.5])
        ylim([3.6e-5 16e-5])
        grid on
        yyaxis right
        plot(x_schnepf,LD,'--r')
        legend([num2str(Days),' day model'],Dstring,'hyphal length densities')
        ylabel(sprintf('Hyphal length density\n \\rho [cm\\cdotcm^-^3]'),'color', 'k');
        ax = gca;
        ax.YColor = 'k'
        
    elseif T==5 && D == 5
        plot(x_points(2:end-1),Y_up(T,:),'-r',(Xexp/10),DATA,'xr','LineWidth',2,'MarkerSize',8)
        title('Phosphate concentration in the soil');
        xlabel('Distance x [cm]');
        ylabel('C_t_o_t [\mumol\cdotcm^-^3]');
        legend([num2str(Days),' day model'],Dstring);
        %             axis tight
        xlim([0 4.5])
        ylim([2.1e-5 10e-5])
        grid on
        yyaxis right
        plot(x_schnepf,LD,'--r')
        legend([num2str(Days),' day model'],Dstring,'hyphal length densities')
        ylabel(sprintf('Hyphal length density\n \\rho [cm\\cdotcm^-^3]'),'color', 'k');
        ax = gca;
        ax.YColor = 'k'
        
    elseif T==5 && D == 6
        plot(x_points(2:end-1),Y_up(T,:),'-r',(Xexp/10),DATA,'xr','LineWidth',2,'MarkerSize',8)
        title('Phosphate concentration in the soil');
        xlabel('Distance x [cm]');
        ylabel('C_t_o_t [\mumol\cdotcm^-^3]');
        legend([num2str(Days),' day model'],Dstring);
        %             axis tight
        xlim([0 4.5])
        ylim([1.95e-5 10e-5])
        grid on
        yyaxis right
        plot(x_schnepf,LD,'--r')
        legend([num2str(Days),' day model'],Dstring,'hyphal length densities')
        ylabel(sprintf('Hyphal length density\n \\rho [cm\\cdotcm^-^3]'),'color', 'k');
        ax = gca;
        ax.YColor = 'k'
        
    end
    
    %Output data to Excel file
    if D==1;        xlswrite('P_uptake_results_no_root_uptake.xlsx',x,'Sheet1','b2:b3');
        xlswrite('P_uptake_results_no_root_uptake.xlsx',SoS,'Sheet1','b4');
        xlswrite('P_uptake_results_no_root_uptake.xlsx',R2,'Sheet1','b5');
    elseif D==2; xlswrite('P_uptake_results_no_root_uptake.xlsx',x,'Sheet1','c2:c3');
        xlswrite('P_uptake_results_no_root_uptake.xlsx',SoS,'Sheet1','c4');
        xlswrite('P_uptake_results_no_root_uptake.xlsx',R2,'Sheet1','c5');
    elseif D==3; xlswrite('P_uptake_results_no_root_uptake.xlsx',x,'Sheet1','d2:d3');
        xlswrite('P_uptake_results_no_root_uptake.xlsx',SoS,'Sheet1','d4');
        xlswrite('P_uptake_results_no_root_uptake.xlsx',R2,'Sheet1','d5');
    elseif D==4; xlswrite('P_uptake_results_no_root_uptake.xlsx',x,'Sheet1','e2:e3');
        xlswrite('P_uptake_results_no_root_uptake.xlsx',SoS,'Sheet1','e4');
        xlswrite('P_uptake_results_no_root_uptake.xlsx',R2,'Sheet1','e5');
    elseif D==5; xlswrite('P_uptake_results_no_root_uptake.xlsx',x,'Sheet1','f2:f3');
        xlswrite('P_uptake_results_no_root_uptake.xlsx',SoS,'Sheet1','f4');
        xlswrite('P_uptake_results_no_root_uptake.xlsx',R2,'Sheet1','f5');
    elseif D==6; xlswrite('P_uptake_results_no_root_uptake.xlsx',x,'Sheet1','g2:g3');
        xlswrite('P_uptake_results_no_root_uptake.xlsx',SoS,'Sheet1','g4');
        xlswrite('P_uptake_results_no_root_uptake.xlsx',R2,'Sheet1','g5');
    end
    
    
end
end