clc
clear
close all;


X=[1e-4;            %initial P concentration value
    3.26e-6];       %initial uptake by the hyphae


LB = [0;        0];        %lower bound
UB = [10e-4;    1e-3];     %upper bound

% read in the P concentrations specificially at positions h1 and h2 for inoculated and controls 
P_h1 = xlsread('hyphal_data.xlsx','Sheet1','P13:P18');
P_h2 = xlsread('hyphal_data.xlsx','Sheet1','q13:q18');
P_h1_control = xlsread('hyphal_data.xlsx','Sheet1','p24:p25');
P_h2_control = xlsread('hyphal_data.xlsx','Sheet1','q24:q25');

% read in the P concentrations standard deviation values at positions h1 and h2 
P_h1_STD = xlsread('hyphal_data.xlsx','Sheet1','R13:R18');
P_h2_STD = xlsread('hyphal_data.xlsx','Sheet1','S13:S18');
P_h1_STD_control = xlsread('hyphal_data.xlsx','Sheet1','R24:R25');
P_h2_STD_control = xlsread('hyphal_data.xlsx','Sheet1','S24:S25');

%P concentrations at points along side arm chamber determined from XRF
P = xlsread('hyphal_data.xlsx','Sheet3','AT16:BK21');
% descritized positions along the side arm chamber
x_schnepf = xlsread('jakobsen_results.xlsx','Sheet2','A1:QI1');
% hyphal length density values computed using hyphal lenght density model at discretized positions along side arm chamber
length_density = xlsread('jakobsen_results.xlsx','Sheet2','A2:QI7');

%seperate the P concentration into the respective sample data sets
P1 = P(1,:);
P2 = P(2,:);
P3 = P(3,:);
P4 = P(4,:);
P5 = P(5,:);
P6 = P(6,:);

%seperate the hyphal length densties into the respective sample data sets
LD1 = length_density(1,:);
LD2 = length_density(2,:);
LD3 = length_density(3,:);
LD4 = length_density(4,:);
LD5 = length_density(5,:);
LD6 = length_density(6,:);

%read in the hyphae lenght density fitting parameters obtained using the jakobsen method
init_condit = xlsread('jakobsen_results.xlsx','Sheet1','B2:G4');
k = init_condit(1,:);
b = init_condit(2,:);
v = init_condit(3,:);

%positions along side aram chamber at which P concentration in known
%from XRF
Xexp = (xlsread('hyphal_data.xlsx','extra_points','AT2:BK2'))*10;

L = 5;    % Length of model domain
Nx=200;   % number of discrete points along domain
x_points=linspace(0,L,Nx+1)';% create a vector of points along the domain
dx=x_points(2)-x_points(1); % spatial discretisation step size
e_up = ones(Nx+1,1); %preallocate a vector with length Nx+1
%create a sparse tridiagonal matrix to be used in the numerical model
D2_up = spdiags(([e_up -2*e_up e_up]./(dx^2)), -1:1, Nx+1, Nx+1);

%plots the function value so the user can moitor the convergence. also
%outputs the iteration data in MATLAB workspace
options = optimset('PlotFcns',@optimplotfval,'Display', 'Iter', 'FinDiffType', 'forward','UseParallel',true);

for D = 1:6 %each of the 6 datasets
    f=@(x)Phosphate_uptake_model_jakobsen_rbm_no_root_uptake(x,x_schnepf,P1,P2,P3,P4,P5,P6,LD1,LD2,LD3,LD4,LD5,LD6,P_h1,P_h2,P_h1_STD,P_h2_STD,...
        P_h1_control,P_h2_control,P_h1_STD_control,P_h2_STD_control,k, b,v,D, 0,x_points, dx, D2_up, Xexp);
    % Use fmincon optimisation algorithm
    problem = createOptimProblem('fmincon','objective',f,'x0',X, 'lb',LB,'ub',UB,'options',options);
    
    %Run a global search using the Fmincon optimisation algorithm
    x = run(GlobalSearch,problem);
    % Phosphate_uptake_model_jakobsen_rbm_no_root_uptake repeated here with a switch to plot the fits only when
    % the optimisation is finished
    Phosphate_uptake_model_jakobsen_rbm_no_root_uptake(x,x_schnepf,P1,P2,P3,P4,P5,P6,LD1,LD2,LD3,LD4,LD5,LD6,P_h1,P_h2,P_h1_STD,P_h2_STD,...
        P_h1_control,P_h2_control,P_h1_STD_control,P_h2_STD_control,k,b,v,D,1,x_points, dx, D2_up, Xexp);
end

