function [SoS,Y_up] = Phosphate_uptake_model_jakobsen_rbm_no_root_uptake(x,x_schnepf,P1,P2,P3,P4,P5,P6,LD1,LD2,LD3,LD4,LD5,LD6,P_h1,P_h2,P_h1_STD,P_h2_STD,P_h1_control,P_h2_control,P_h1_STD_control,P_h2_STD_control,k,b,v,D,plots,x_points, dx, D2_up,Xexp)

C0=x(1);        % initial P concentration value
% F_max=x(2);   %originally root uptake was considered in the model but has been switched off
F_max_m=x(2);   %initial uptake by the hyphae

%initialise the data for the different sample sets
if D==1;        DATA = P1;  LD = LD1;  k = k(1);   d=0; b=b(1);    v=v(1);     T=4;    Days = 14;  Dstring=sprintf('Phosphorous absent, two week,\n replicate two P counts');
elseif D==2;    DATA = P2;  LD = LD2;  k = k(2);   d=0; b=b(2);    v=v(2);     T=4;    Days = 14;  Dstring=sprintf('Phosphorous present, two week,\n replicate one P counts');
elseif D==3;    DATA = P3;  LD = LD3;  k = k(3);   d=0; b=b(3);    v=v(3);     T=4;    Days = 14;  Dstring=sprintf('Phosphorous present, two week,\n replicate two P counts');
elseif D==4;    DATA = P4;  LD = LD4;  k = k(4);   d=0; b=b(4);    v=v(4);     T=5;    Days = 28;  Dstring=sprintf('Phosphorous absent, four week,\n replicate two P counts');
elseif D==5;    DATA = P5;  LD = LD5;  k = k(5);   d=0; b=b(5);    v=v(5);     T=5;    Days = 28;  Dstring=sprintf('Phosphorous absent, four week,\n replicate three P counts');
elseif D==6;    DATA = P6;  LD = LD6;	k = k(6);   d=0; b=b(6);    v=v(6);     T=5;    Days = 28;  Dstring=sprintf('Phosphorous present, four week,\n replicate two P counts');
end

% phosphate concentrations at positions h1 and h2 for each of the sample
% sets
set_1 = [P_h1(1),P_h2(1)];
set_2 = [P_h1(2),P_h2(2)];
set_3 = [P_h1(3),P_h2(3)];
set_4 = [P_h1(4),P_h2(4)];
set_5 = [P_h1(5),P_h2(5)];
set_6 = [P_h1(6),P_h2(6)];
set_1_control = [P_h1_control(1),P_h2_control(1)];
set_2_control = [P_h1_control(2),P_h2_control(2)];


% phosphate standard deviation values at positions h1 and h2 for each of 
%the sample sets
set_1_error = [P_h1_STD(1),P_h2_STD(1)];
set_2_error = [P_h1_STD(2),P_h2_STD(2)];
set_3_error = [P_h1_STD(3),P_h2_STD(3)]; 
set_4_error = [P_h1_STD(4),P_h2_STD(4)]; 
set_5_error = [P_h1_STD(5),P_h2_STD(5)];
set_6_error = [P_h1_STD(6),P_h2_STD(6)]; 
set_1_control_error = [P_h1_STD_control(1),P_h2_STD_control(1)];
set_2_control_error = [P_h1_STD_control(2),P_h2_STD_control(2)];

h1_values_2_week = [set_1(1),set_2(1),set_3(1),set_1_control(1)];
h2_values_2_week = [set_1(2),set_2(2),set_3(2),set_1_control(2)];

h1_values_4_week = [set_4(1),set_5(1),set_6(1),set_2_control(1)];
h2_values_4_week = [set_4(2),set_5(2),set_6(2),set_2_control(2)];

h1_2_week_error_values = [set_1_error(1),set_2_error(1),set_3_error(1),set_1_control_error(1)];
h2_2_week_error_values = [set_1_error(2),set_2_error(2),set_3_error(2),set_1_control_error(2)];

h1_4_week_error_values = [set_4_error(1),set_5_error(1),set_6_error(1),set_2_control_error(1)];
h2_4_week_error_values = [set_4_error(2),set_5_error(2),set_6_error(2),set_2_control_error(2)];

concentrations_2_week_plot = [h1_values_2_week; h2_values_2_week];
concentrations_4_week_plot = [h1_values_4_week; h2_values_4_week];
errbar_2_week = [h1_2_week_error_values; h2_2_week_error_values];
errbar_4_week = [h1_4_week_error_values;h2_4_week_error_values];

t=28*3600*24; %time in hours

C = 0*x_points+C0;              %initial concentration
F_max=3.26e-6;                  % Root uptake
tout=[0,3,7,14,28]*3600*24;     %output times


theta = 0.3;        %  liquid phase volume fraction
D_l = 1.05e-8;      %  diffusion coefficient
fl = 0.308;         %  impedence factor
r_m = 5e-4;         % radius of external hyphae [cm]


%stiff differential equation solver ode15 used to compute the uptake
[~,Y_up] = ode15s(@tstep_up,tout,C(2:end-1),[], d, dx, x_points, D, b, v, k, pi, r_m, F_max, F_max_m, theta, D_l, fl, D2_up,C0);


    function [ddt_up, up_f] = tstep_up(t, u, d, dx, x_points, D, b,v, k, pi, r_m, F_max, F_max_m, theta, D_l, fl, D2_up,C0)
        
        
        u_0 = -(theta*D_l*fl)*(((4/(2*dx))*u(1))+((-1/(2*dx))*u(2)))/...
            ((theta*D_l*fl)*(-3/(2*dx))-F_max);                             %initial phospate concentration at position 0 (updated on each iteration cycle)
        c = [u_0;u;C0];                                                     %initial concentration of solutes at time zero
        
        rho_a = k*exp((b/v).*x_points).*(-((1/v)*(x_points-t*v)));          % hyphae length density
        
        % there is a strong oscillatory response in the model which is
        % caused by the (very) non-smooth function
        %         rho_a(x>(v*t))=0;
        % to damp these oscillations we multiply the P concentration by
        % a heaviside function. The function goes to zero in a
        % differentiable way over 2 grid points
        
        rho_a=rho_a.*1/2.*(1-tanh((x_points-v*t)/(sqrt(2)*4*dx)));           % hyphae length density multipled by heaviside function
        r_myc = (2*pi*r_m).*rho_a.*((F_max_m.*c));                           % uptake of P by hyphae
        ct = (theta*D_l*fl)*D2_up(2:end-1,:)*c-r_myc(2:end-1);               % P concentration
        ddt_up=ct;
        up_f = r_myc;
        
    end

SoS = sum((DATA-interp1(x_points(2:end-1),Y_up(T,:),Xexp/10)).^2)./sum((DATA-mean(DATA)).^2);
R2=(1-SoS);


%Plot results
if plots
    % plot the p concentrations at locations h1 and h2
    figure(2) % 2 weeek P concentrations
    barwitherr(errbar_2_week, concentrations_2_week_plot);% Plot with errorbars
    title(sprintf('Two week P concentration'));
    %xlabel('Distance x [cm]');
    ylabel('C_t_o_t (\mumol/cm^3)');
    grid off
    colormap(gray)
    caxis([0 4])
    %  axis([0.5 2.6 -0.000015 0.00028]);
    axis([0.5 2.6 0 0.00028]);
    xticks([0.5 1 2])
    % xticklabels({'','h1 = 1.35','h2 = 2.85'});
    xticklabels({'0','h1','h2'})
    set(gca,'box','off')
    set(gca,'linewidth',2);
    %     h5 = annotation('arrow');
    %     h5.Parent = gca;           % associate the arrow the the current axes
    %     h5.X = [1 1];          % the location in data units
    %     h5.Y = [(3.5e-4), (-1.5e-5)];
    %
    %     h6 = annotation('arrow');
    %     h6.Parent = gca;           % associate the arrow the the current axes
    %     h6.X = [2 2];          % the location in data units
    %     h6.Y = [(3.5e-4), (-1.5e-5)];
    % hold on
    %     xl = [0.166 0.166];
    %     yl = [0.110 0.89];
    %     annotation('line',xl,yl);
    %     x2_arrow = [2.5      0.455;     2.5        0.5;    2.6   0.545];
    %     y2_arrow = [0.1E-4  0.00026;    -0.1E-4 0.00028;    0   0.00026];
    %     patch(x2_arrow,y2_arrow,'k');
    legend ('IP-, replicate two',...
        'IP+, replicate one',...
        'IP+, replicate two',...
        'CP+ averaged replicates');
   
    figure(3)% 4 weeek P concentrations
    barwitherr(errbar_4_week, concentrations_4_week_plot);% Plot with errorbars
    title(sprintf('Four week P concentration'));
    %xlabel('Distance x [cm]');
    ylabel('C_t_o_t (\mumol/cm^3)');
    grid off
    colormap(gray)
    caxis([0 4])
    axis([0.5 2.6 0 0.00025]);
    xticks([0.5 1 2])
    % xticklabels({'','h1 = 1.35','h2 = 2.85'});
    xticklabels({'0','h1','h2'})
    set(gca,'box','off')
    set(gca,'linewidth',2);
    %     h5 = annotation('arrow');
    %     h5.Parent = gca;           % associate the arrow the the current axes
    %     h5.X = [1 1];          % the location in data units
    %     h5.Y = [(3.5e-4), (-2.0e-5)];
    %
    %     h6 = annotation('arrow');
    %     h6.Parent = gca;           % associate the arrow the the current axes
    %     h6.X = [2 2];          % the location in data units
    %     h6.Y = [(3.5e-4), (-2.0e-5)];
    % hold on
    %     xl = [0.166 0.166];
    %     yl = [0.110 0.89];
    %     annotation('line',xl,yl);
    %     x2_arrow = [2.5      0.455;     2.5        0.5;    2.6   0.545];
    %     y2_arrow = [0.1E-4  0.00023;    -0.1E-4 0.00025;    0   0.00023];
    %     patch(x2_arrow,y2_arrow,'k');
    legend ('IP-, replicate two',...
        'IP-, replicate three',...
        'IP+, replicate two',...
        'CP-, averaged replicates');
   
    figure(4);% plot the model fits
    subplot(3,2,D);
    
    if T==4 && D == 1
        plot(x_points(2:end-1),Y_up(T,:),'-b',(Xexp/10),DATA,'xb','LineWidth',2,'MarkerSize',8)
        title('Phosphate concentration in the soil');
        xlabel('Distance x [cm]');
        ylabel('C_t_o_t [\mumol\cdotcm^-^3]');
        legend([num2str(Days),' day model'],Dstring);
        xlim([0 4.5])
        ylim([4.4e-5 13e-5])
        grid on
        yyaxis right
        plot(x_schnepf,LD,'--b')
        legend([num2str(Days),' day model'],Dstring,'Hyphal length density')
        ylabel(sprintf('Hyphal length density\n \\rho [cm\\cdotcm^-^3]'),'color', 'k');
        ax = gca;
        ax.YColor = 'k';
        
    elseif T==4 && D == 2
        plot(x_points(2:end-1),Y_up(T,:),'-b',(Xexp/10),DATA,'xb','LineWidth',2,'MarkerSize',8)
        title('Phosphate concentration in the soil');
        xlabel('Distance x [cm]');
        ylabel('C_t_o_t [\mumol\cdotcm^-^3]');
        legend([num2str(Days),' day model'],Dstring);
        xlim([0 4.5])
        ylim([4.6e-5 15e-5])
        grid on
        yyaxis right
        plot(x_schnepf,LD,'--b')
        legend([num2str(Days),' day model'],Dstring,'Hyphal length density')
        ylabel(sprintf('Hyphal length density\n \\rho [cm\\cdotcm^-^3]'),'color', 'k');
        ax = gca;
        ax.YColor = 'k';
        
    elseif T==4 && D == 3
        plot(x_points(2:end-1),Y_up(T,:),'-b',(Xexp/10),DATA,'xb','LineWidth',2,'MarkerSize',8)
        title('Phosphate concentration in the soil');
        xlabel('Distance x [cm]');
        ylabel('C_t_o_t [\mumol\cdotcm^-^3]');
        legend([num2str(Days),' day model'],Dstring);
        xlim([0 4.5])
        ylim([4.8e-5 14e-5])
        grid on
        yyaxis right
        plot(x_schnepf,LD,'--b')
        legend([num2str(Days),' day model'],Dstring,'Hyphal length density')
        ylabel(sprintf('Hyphal length density\n \\rho [cm\\cdotcm^-^3]'),'color', 'k');
        ax = gca;
        ax.YColor = 'k';
        
    elseif T==5 && D == 4
        plot(x_points(2:end-1),Y_up(T,:),'-r',(Xexp/10),DATA,'xr','LineWidth',2,'MarkerSize',8)
        title('Phosphate concentration in the soil');
        xlabel('Distance x [cm]');
        ylabel('C_t_o_t [\mumol\cdotcm^-^3]');
        legend([num2str(Days),' day model'],Dstring);
        xlim([0 4.5])
        ylim([3.8e-5 15e-5])
        grid on
        yyaxis right
        plot(x_schnepf,LD,'--r')
        legend([num2str(Days),' day model'],Dstring,'Hyphal length density')
        ylabel(sprintf('Hyphal length density\n \\rho [cm\\cdotcm^-^3]'),'color', 'k');
        ax = gca;
        ax.YColor = 'k';
        
    elseif T==5 && D == 5
        plot(x_points(2:end-1),Y_up(T,:),'-r',(Xexp/10),DATA,'xr','LineWidth',2,'MarkerSize',8)
        title('Phosphate concentration in the soil');
        xlabel('Distance x [cm]');
        ylabel('C_t_o_t [\mumol\cdotcm^-^3]');
        legend([num2str(Days),' day model'],Dstring);
        xlim([0 4.5])
        ylim([2.2e-5 10e-5])
        grid on
        yyaxis right
        plot(x_schnepf,LD,'--r')
        legend([num2str(Days),' day model'],Dstring,'Hyphal length density')
        ylabel(sprintf('Hyphal length density\n \\rho [cm\\cdotcm^-^3]'),'color', 'k');
        ax = gca;
        ax.YColor = 'k';
        
    elseif T==5 && D == 6
        plot(x_points(2:end-1),Y_up(T,:),'-r',(Xexp/10),DATA,'xr','LineWidth',2,'MarkerSize',8)
        title('Phosphate concentration in the soil');
        xlabel('Distance x [cm]');
        ylabel('C_t_o_t [\mumol\cdotcm^-^3]');
        legend([num2str(Days),' day model'],Dstring);
        xlim([0 4.5])
        ylim([1.9e-5 10e-5])
        grid on
        yyaxis right
        plot(x_schnepf,LD,'--r')
        legend([num2str(Days),' day model'],Dstring,'Hyphal length density')
        ylabel(sprintf('Hyphal length density\n \\rho [cm\\cdotcm^-^3]'),'color', 'k');
        ax = gca;
        ax.YColor = 'k';
    end
    
    %Output data to Excel file
    if D==1;        xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',x,'Sheet1','b2:b4');
        xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',SoS,'Sheet1','b5');
        xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',R2,'Sheet1','b6');
    elseif D==2; xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',x,'Sheet1','c2:c4');
        xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',SoS,'Sheet1','c5');
        xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',R2,'Sheet1','c6');
    elseif D==3; xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',x,'Sheet1','d2:d4');
        xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',SoS,'Sheet1','d5');
        xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',R2,'Sheet1','d6');
    elseif D==4; xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',x,'Sheet1','e2:e4');
        xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',SoS,'Sheet1','e5');
        xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',R2,'Sheet1','e6');
    elseif D==5; xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',x,'Sheet1','f2:f4');
        xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',SoS,'Sheet1','f5');
        xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',R2,'Sheet1','f6');
    elseif D==6; xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',x,'Sheet1','g2:g4');
        xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',SoS,'Sheet1','g5');
        xlswrite('P_uptake_results_jakobsen_no_root_uptake.xlsx',R2,'Sheet1','g6');
    end
    
    
end
end